@@ -39,7 +39,7 @@ def sulg_format_parse(page: dict, s: str):
     sulg_dcit["hour"] = page.get("date").strftime("%H")
     sulg_dcit["minute"] = page.get("date").strftime("%M")
     sulg_dcit["second"] = page.get("date").strftime("%S")
-    sulg_dcit["title"] = page.get("title","")  
+    sulg_dcit["title"] = page.get("title","").replace(" ", "")  
     category = page.get("category")  
     sulg_dcit["category"] = "/".join(category) if category else ""
     sulg_dcit["name"] = page.get("name","")
@@ -59,7 +59,7 @@ def read_post_file(hexo_post_path,sulg_format):
         index += 1
         # sulg = fp.removeprefix(hexo_post_path).lstrip("/").rstrip(".md")
         title = os.path.relpath(fp, hexo_post_path).replace(" ", "")
-        name = os.path.basename(fp).rstrip(".md").replace(" ", "")
+        name = os.path.basename(fp).rstrip(".md").strip()
 
         with open(fp, "r", encoding="utf-8") as mdFile:
             # Preprocess the Markdown frontmatter into yaml code fences
@@ -125,7 +125,7 @@ def import_notion(token_v2, database_url,bloglist,):
             row = cv.collection.add_row()
             row.type = "Post"
             row.status= "Published"
-            row.title=page.get("title") 
+            row.title=page.get("name") 
             row.summary=content[0:200]+"..."
             row.slug= page.get("sulg") 
             category =  page.get("category")
